==> pydantic_schemaorg-0.0.5-py2.py3-none-any.whl: pydantic_schemaorg/AnatomicalStructure.py <==
from pydantic import Field
from typing import Any, Optional, Union, List
from pydantic_schemaorg.MedicalEntity import MedicalEntity


class AnatomicalStructure(MedicalEntity):
    """Any part of the human body, typically a component of an anatomical system. Organs, tissues,"
     "and cells are all anatomical structures.

    See https://schema.org/AnatomicalStructure.

    """
    type_: str = Field("AnatomicalStructure", const=True, alias='@type')
    diagram: Any = Field(
        None,
        description="An image containing a diagram that illustrates the structure and/or its component substructures"
     "and/or connections with other structures.",
    )
    subStructure: Any = Field(
        None,
        description="Component (sub-)structure(s) that comprise this anatomical structure.",
    )
    connectedTo: Any = Field(
        None,
        description="Other anatomical structures to which this structure is connected.",
    )
    relatedCondition: Any = Field(
        None,
        description="A medical condition associated with this anatomy.",
    )
    bodyLocation: Optional[Union[List[str], str]] = Field(
        None,
        description="Location in the body of the anatomical structure.",
    )
    relatedTherapy: Any = Field(
        None,
        description="A medical therapy related to this anatomy.",
    )
    partOfSystem: Any = Field(
        None,
        description="The anatomical or organ system that this structure is part of.",
    )
    associatedPathophysiology: Optional[Union[List[str], str]] = Field(
        None,
        description="If applicable, a description of the pathophysiology associated with the anatomical"
     "system, including potential abnormal changes in the mechanical, physical, and biochemical"
     "functions of the system.",
    )
    

AnatomicalStructure.update_forward_refs()

==> pydantic_schemaorg-0.1.0-py2.py3-none-any.whl: pydantic_schemaorg/AnatomicalStructure.py <==
from pydantic import Field
from pydantic_schemaorg.ImageObject import ImageObject
from typing import List, Optional, Any, Union
from pydantic_schemaorg.MedicalCondition import MedicalCondition
from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
from pydantic_schemaorg.AnatomicalSystem import AnatomicalSystem
from pydantic_schemaorg.MedicalEntity import MedicalEntity


class AnatomicalStructure(MedicalEntity):
    """Any part of the human body, typically a component of an anatomical system. Organs, tissues,"
     "and cells are all anatomical structures.

    See https://schema.org/AnatomicalStructure.

    """
    type_: str = Field("AnatomicalStructure", const=True, alias='@type')
    diagram: Optional[Union[List[Union[ImageObject, str]], Union[ImageObject, str]]] = Field(
        None,
        description="An image containing a diagram that illustrates the structure and/or its component substructures"
     "and/or connections with other structures.",
    )
    subStructure: Optional[Union[List[Union['AnatomicalStructure', str]], Union['AnatomicalStructure', str]]] = Field(
        None,
        description="Component (sub-)structure(s) that comprise this anatomical structure.",
    )
    connectedTo: Optional[Union[List[Union['AnatomicalStructure', str]], Union['AnatomicalStructure', str]]] = Field(
        None,
        description="Other anatomical structures to which this structure is connected.",
    )
    relatedCondition: Optional[Union[List[Union[MedicalCondition, str]], Union[MedicalCondition, str]]] = Field(
        None,
        description="A medical condition associated with this anatomy.",
    )
    bodyLocation: Optional[Union[List[str], str]] = Field(
        None,
        description="Location in the body of the anatomical structure.",
    )
    relatedTherapy: Optional[Union[List[Union[MedicalTherapy, str]], Union[MedicalTherapy, str]]] = Field(
        None,
        description="A medical therapy related to this anatomy.",
    )
    partOfSystem: Optional[Union[List[Union[AnatomicalSystem, str]], Union[AnatomicalSystem, str]]] = Field(
        None,
        description="The anatomical or organ system that this structure is part of.",
    )
    associatedPathophysiology: Optional[Union[List[str], str]] = Field(
        None,
        description="If applicable, a description of the pathophysiology associated with the anatomical"
     "system, including potential abnormal changes in the mechanical, physical, and biochemical"
     "functions of the system.",
    )
    

AnatomicalStructure.update_forward_refs()
